# Changelog

All notable changes to this project will be documented in this file. If you are interested in bug fixes, enhancements etc., best follow the project on GitHub.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.1.0] - 2023-10-01

### Added

- Helper classes for Keys and Values to make it possible to bypass behaviour.

### Fixed

- Issue of tuple keys. It was not possible to define subdictionaries with tuple keys. Now
  it is possible with the provided `Key` helper class.

### Changed

### Removed
